package com.zjsgfa.project.zjsgfa.mapper;

import java.util.List;
import com.zjsgfa.project.zjsgfa.domain.SjQkztfx;

/**
 * 设计-区块钻头分析Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-22
 */
public interface SjQkztfxMapper 
{
    /**
     * 查询设计-区块钻头分析
     * 
     * @param id 设计-区块钻头分析主键
     * @return 设计-区块钻头分析
     */
    public SjQkztfx selectSjQkztfxById(Long id);

    /**
     * 查询设计-区块钻头分析列表
     * 
     * @param sjQkztfx 设计-区块钻头分析
     * @return 设计-区块钻头分析集合
     */
    public List<SjQkztfx> selectSjQkztfxList(SjQkztfx sjQkztfx);

    /**
     * 新增设计-区块钻头分析
     * 
     * @param sjQkztfx 设计-区块钻头分析
     * @return 结果
     */
    public int insertSjQkztfx(SjQkztfx sjQkztfx);

    /**
     * 修改设计-区块钻头分析
     * 
     * @param sjQkztfx 设计-区块钻头分析
     * @return 结果
     */
    public int updateSjQkztfx(SjQkztfx sjQkztfx);

    /**
     * 删除设计-区块钻头分析
     * 
     * @param id 设计-区块钻头分析主键
     * @return 结果
     */
    public int deleteSjQkztfxById(Long id);

    /**
     * 批量删除设计-区块钻头分析
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSjQkztfxByIds(Long[] ids);

    int deleteSjQkztfxByJh(String jh);

    int insertSjQkztfxBatch(List<SjQkztfx> sjQkztfxList);

}
